@@ -162,7 +162,7 @@ class ArgsParser(BareConfig):
                              help = 'Update all overlays.')
 
         #-----------------------------------------------------------------
-        # Additional Options
+        # Path Options
 
         path_opts = self.parser.add_argument_group('<Path options>')
 
@@ -261,6 +261,16 @@ class ArgsParser(BareConfig):
                               'not required as layman is capable of detecting the '
                               'available number of columns automatically.')
 
+        #-----------------------------------------------------------------
+        # Additional Options
+        etc_opts = self.parser.add_argument_group('<Additional options>')
+
+        etc_opts.add_argument('--protocol_filter',
+                              nargs = '+',
+                              help = 'Sets the protocol filter that determines '
+                              'which protocols will be used when adding '
+                              'overlays or updating their source URLs.')
+
         #-----------------------------------------------------------------
         # Debug Options
 
@@ -346,7 +356,19 @@ class ArgsParser(BareConfig):
                 storage = self.options[key]
             if storage:
                 return storage
-                
+
+        if key == 'protocol_filter':
+            protocol_filter = []
+            if (key in self.options.keys()
+                and not self.options[key] is None):
+                protocol_filter = self.options[key]
+            if self.config.has_option('MAIN', 'protocol_filter'):
+                protocol_filter = self.config.get('MAIN', 'protocol_filter')
+            if protocol_filter:
+                if not isinstance(protocol_filter, list):
+                    protocol_filter = [e.strip() for e in protocol_filter.split(',')]
+                return protocol_filter
+
         if key == 'overlays':
             overlays = ''
             if (key in self.options.keys()
