@@ -96,9 +96,11 @@ class BareConfig(object):
             'cache'     : '%(storage)s/cache',
             'local_list': '%(storage)s/overlays.xml',
             'installed': '%(storage)s/installed.xml',
+            'protocol_filter': [],
             'auto_sync': 'No',
             'check_official': 'Yes',
-            'conf_type': 'make.conf',
+            'conf_type': 'repos.conf',
+            'db_type': 'xml',
             'require_repoconfig': 'Yes',
             'clean_archive': 'yes',
             'make_conf' : '%(storage)s/make.conf',
